@@ -1,8 +1,9 @@
 package Mail::Milter::Authentication::Handler::RSpamD;
 use strict;
 use warnings;
+use Mail::Milter::Authentication 2.20180510;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180318'; # VERSION
+our $VERSION = '2.20180510'; # VERSION
 # #ABSTRACT: RSpamD scanning for Authentication Milter
 
 use English qw{ -no_match_vars };
@@ -181,6 +182,7 @@ sub eom_callback {
 
     my $j = JSON->new();
     my $rspamd_data = eval{ $j->decode( $response->{'content'} ); };
+    $self->handle_exception( $@ );
     if ( ! exists( $rspamd_data->{'default'} ) ) {
         $self->log_error( 'RSpamD bad data from server' );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-rspam' )->safe_set_value( 'temperror' );
@@ -267,7 +269,7 @@ Mail::Milter::Authentication::Handler::RSpamD
 
 =head1 VERSION
 
-version 2.20180318
+version 2.20180510
 
 =head1 DESCRIPTION
 
